using AutoMapper;
using CatalogService.Data;
using CatalogService.DTOs;
using CatalogService.Entities;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Shared.DTOs;

namespace CatalogService.Controllers;

[ApiController]
[Route("api/[controller]")]
public class ExercicesController : ControllerBase
{
    private readonly CatalogDbContext _context;
    private readonly IMapper _mapper;

    public ExercicesController(CatalogDbContext context, IMapper mapper)
    {
        _context = context;
        _mapper = mapper;
    }
    
    [Authorize]
    [HttpPost]
    public async Task<IActionResult> Create([FromBody] CreateExerciceTemplateDto dto)
    {
        if (User.Identity.Name != "admin") return Forbid();
        
        var exercice = _mapper.Map<Exercice>(dto);
        _context.Exercices.Add(exercice);
        await _context.SaveChangesAsync();
        return CreatedAtAction(nameof(GetById), new { id = exercice.Id }, _mapper.Map<ExerciceTemplateDto>(exercice));
    }

    [Authorize]
    [HttpPut("{id}")]
    public async Task<IActionResult> Update(string id, [FromBody] UpdateExerciceTemplateDto dto)
    {
        if (User.Identity.Name != "admin") return Forbid();
        
        var exercice = await _context.Exercices.FindAsync(id);
        if (exercice == null) return NotFound();

        _mapper.Map(dto, exercice);
        exercice.UpdatedAt = DateTime.UtcNow;
        await _context.SaveChangesAsync();
        return NoContent();
    }

    [Authorize]
    [HttpDelete("{id}")]
    public async Task<IActionResult> Delete(string id)
    {
        if (User.Identity.Name != "admin") return Forbid();
        
        var exercice = await _context.Exercices.FindAsync(id);
        if (exercice == null) return NotFound();

        _context.Exercices.Remove(exercice);
        await _context.SaveChangesAsync();
        return NoContent();
    }

    [Authorize]
    [HttpGet("{id}")]
    public async Task<ActionResult<ExerciceTemplateDto>> GetById(string id)
    {
        if (User.Identity.Name != "admin") return Forbid();
        
        var exercice = await _context.Exercices.FindAsync(id);
        if (exercice == null) return NotFound();

        return _mapper.Map<ExerciceTemplateDto>(exercice);
    }
}